<?php
// If this file is called directly, abort.
if (!defined( 'POSTIT_LT_VERSION' )) {
	die;
}

class postitAdmin extends postitBase{
	
	public function run(){
		$this->initActions();
		$this->initFilters();
	}
	
	public function initActions(){
		add_action('admin_menu', [$this, 'action_register_options_page']);
		add_action('admin_init', [$this, 'action_register_settings']);
	}
	
	public function initFilters(){
		add_filter('plugin_action_links_' . plugin_basename( $this->getPluginDirPath() . 'postit.php'), [$this, 'filter_add_action_links'], 10, 4);
	}

	public function options_page(){
		require 'partials/options.php';
	}
	
	public function action_register_options_page() {
		add_options_page(__('Postit.lt API', 'postit-lt'), __('Postit.lt API', 'postit-lt'), 'manage_options', self::PLUGIN_NAME, [$this, 'options_page']);
	}
	
	public function action_register_settings() {
		register_setting('postit_options_group', 'postit_api_key', [
			'type' => 'string', 
			'show_in_rest' => false,
			'default' => '',
		]);
		
		register_setting('postit_options_group', 'postit_options', [
			'type' => 'string', 
			'sanitize_callback' => [$this, 'sanitize_options'],
			'show_in_rest' => false,
			'default' => '',
		]);
	}
	
	public function filter_add_action_links($links) {
		$settings_link = [
			'<a href="' . admin_url( 'options-general.php?page='.self::PLUGIN_NAME) . '">' . __('Settings', 'postit-lt') . '</a>',
		];
		return array_merge($settings_link, $links);
	}
	
	public function sanitize_options($value){
		$default = $this->getSettings('default');
		if(is_array($default) && is_array($value)){
			$value['only_woo_checkout'] = empty($value['only_woo_checkout']) ? 0 : 1;
			$value = array_replace($default, $value);
		}
		return $value;
	}
	
	public function isValidApiKey($key){
		if(empty($key)){
			return false;
		}
		
		$api_urls = $this->getSettings('api_urls', []);
		if(!is_array($api_urls) || !isset($api_urls['v1'])){
			return false;
		}
		
		$url = $api_urls['v1'].'?'.http_build_query(['term' => '00001', 'key' => $key]);
		$response = wp_remote_get($url, ['timeout' => 10]);
		if(!$response || !isset($response['body'])){
			return false;
		}
		
		$data = json_decode($response['body'], true);
		return ($data && !empty($data['success']));
	}
}












